{% extends "formset/default/widgets/file.html" %}
{% load i18n %}

{% block "choose-file" %}
<button type="button" class="dj-choose-file">{% trans "Choose file" %}</button>
{% endblock %}

{% block "file-caption" %}
<figcaption>
	<dl>
		<dt class="font-semibold">{% trans 'Name' %}:</dt>
		<dd>${name}</dd>
	</dl>
	<dl>
		<dt class="font-semibold">{% trans 'Content-Type (Size)' %}:</dt>
		<dd>${content_type} (${size})</dd>
	</dl>
	<a class="dj-delete-file">{% trans "Delete" %}</a>
	<a class="dj-download-file" href="${download_url}" download="${name}">{% trans "Download" %}</a>
</figcaption>
{% endblock %}
