{% extends "formset/default/buttons/remove_collection.html" %}
{% block "button-classes" %} inline-flex justify-center py-1 px-1 border border-transparent shadow-sm text-sm font-medium rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2{% endblock %}
