{% spaceless %}
<django-field-group{% with css_classes=field.css_classes %}{% if css_classes %} class="{{ css_classes }}"{% endif %}{% endwith %}>
	{{ field.label_tag }}
	{{ field }}
	{{ field.errors }}
	{% with help_text=field.help_text %}
		{% if help_text %}<p class="help">{{ help_text }}</p>{% endif %}
	{% endwith %}
</django-field-group>
{% endspaceless %}
